.. django-cloud-storages documentation master file, created by
   sphinx-quickstart on Fri Jun 30 17:42:08 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-cloud-storages's documentation!
=================================================

django-cloud-storages is a package developed for django to work with cloud storages to store/upload media files.

At the moment this package support the following cloud storage services -

.. toctree::
   :maxdepth: 1
   :glob:

   backends/*

Installation
************

Use pip to install from PyPI::

   pip install django-cloud-storages

It will install all the cloud storage backends (available in this package), you can choose any of the storage backend as per your requirement.

Contributing
************

To contribute to django-cloud-storages `create a fork`_ on GitHub. Clone your fork, make some changes, and submit a pull request.

.. _create a fork: https://github.com/Samiddha99/django-cloud-storages

Issues
******

Use the GitHub `issue tracker`_ for django-cloud-storages to submit bugs, issues, and feature requests.

.. _issue tracker: https://github.com/Samiddha99/django-cloud-storages/issues

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
